@@ -45,20 +45,18 @@ def _find_violating_priv_uses(variable, current_scope):
                 traverse_scope = traverse_scope.parent
 
             if not private_var_was_set:
-                msg = ("Referenced external private"
-                       " variable {0}").format(use)
-                yield LinterFailure(msg,
-                                    variable.node.line,
-                                    variable.node.col)
+                yield (use, variable.node.line)
 
 
 def only_use_own_priv_vars(ast):
     """Check that all private variables used are defined here."""
-    all_errors = []
+    used_privs = []
 
     global_set_vars = find_variables_in_scopes.set_in_tree(ast)
     global_used_vars = find_variables_in_scopes.used_in_tree(ast)
 
+    _, global_definitions = find_all.private_calls_and_definitions(ast)
+
     # The big assumption here is that the "scopes" structure in both
     # trees are the same
     def _scope_visitor(set_vars_scope, used_vars_scope):
@@ -73,15 +71,15 @@ def only_use_own_priv_vars(ast):
             _scope_visitor(set_vars_scope.scopes[index],
                            used_vars_scope.scopes[index])
 
-        errors = []
-
         for variable in used_vars_scope.used_vars:
-            errors += list(_find_violating_priv_uses(variable,
-                                                     set_vars_scope))
-
-        for error in errors:
-            all_errors.append(error)
+            used_privs.extend(list(_find_violating_priv_uses(variable,
+                                                             set_vars_scope)))
 
     _scope_visitor(global_set_vars, global_used_vars)
 
-    return all_errors
+    # Filter out definitions of private functions of the same name
+    # as functions can be used as variables.
+    used_privs = [up for up in used_privs if up[0] not in global_definitions]
+
+    err_msg = "Referenced external private variable {0}"
+    return [LinterFailure(err_msg.format(u[0]), u[1]) for u in used_privs]
